|
From: <caw...@us...> - 2007-01-15 15:37:04
|
Revision: 1772
http://svn.sourceforge.net/rubyeclipse/?rev=1772&view=rev
Author: cawilliams
Date: 2007-01-15 07:36:59 -0800 (Mon, 15 Jan 2007)
Log Message:
-----------
fix broken test
Modified Paths:
--------------
trunk/org.rubypeople.rdt.core.tests/src/org/rubypeople/rdt/internal/core/TC_RubyProject.java
Modified: trunk/org.rubypeople.rdt.core.tests/src/org/rubypeople/rdt/internal/core/TC_RubyProject.java
===================================================================
--- trunk/org.rubypeople.rdt.core.tests/src/org/rubypeople/rdt/internal/core/TC_RubyProject.java 2007-01-15 15:29:21 UTC (rev 1771)
+++ trunk/org.rubypeople.rdt.core.tests/src/org/rubypeople/rdt/internal/core/TC_RubyProject.java 2007-01-15 15:36:59 UTC (rev 1772)
@@ -7,7 +7,6 @@
import org.eclipse.core.runtime.IProgressMonitor;
import org.rubypeople.rdt.core.IRubyProject;
import org.rubypeople.rdt.core.IRubyScript;
-import org.rubypeople.rdt.core.RubyModelException;
import org.rubypeople.rdt.core.tests.ModifyingResourceTest;
public class TC_RubyProject extends ModifyingResourceTest {
@@ -76,10 +75,13 @@
}
/**
* Test that a ruby script
* has a corresponding resource.
*/
- public void testRubyScriptCorrespondingResource() throws RubyModelException {
+ public void testRubyScriptCorrespondingResource() throws CoreException {
+ addRubyNature("RubyProjectTests");
+ createFolder("RubyProjectTests/q");
+ createFile("RubyProjectTests/q/A.rb", "");
IRubyScript element= getRubyScript("RubyProjectTests", "", "q", "A.rb");
IResource corr= element.getCorrespondingResource();
IResource res= getWorkspace().getRoot().getProject("RubyProjectTests").getFolder("q").getFile("A.rb");
@@ -76,10 +75,13 @@
}
/**
- * Test that a ruby script
- * has a corresponding resource.
+ * Test that a ruby script has a corresponding resource.
+ * @throws CoreException
*/
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|